@@ -1,3 +1,8 @@
+### Dstat battery plugin
+### Displays battery information from ACPI
+###
+### Authority: dag@wieers.com
+
 global string
 import string
 
@@ -5,7 +10,13 @@ class dstat_battery(dstat):
 	def __init__(self):
 		self.name = 'battery'
 		self.format = ('f', 4, 34)
-		self.vars = os.listdir('/proc/acpi/battery/')
+		self.vars = []
+		for battery in os.listdir('/proc/acpi/battery/'):
+			for line in dopen('/proc/acpi/battery/'+battery+'/state').readlines():
+				l = string.split(line)
+				if len(l) < 2: continue
+				if l[0] == 'present:' and l[1] == 'yes':
+					self.vars.append(battery)
 #		self.nick = [string.lower(name) for name in self.vars]
 		self.nick = []
 		for name in self.vars:
@@ -26,6 +37,9 @@ class dstat_battery(dstat):
 				if l[0] == 'remaining':
 					current = int(l[2])
 					break
-			self.val[battery] = current * 100.0 / full
+			if current:
+				self.val[battery] = current * 100.0 / full
+			else:
+				self.val[battery] = -1
 
 # vim:ts=4:sw=4
