@@ -21,9 +21,9 @@ class dstat_cpufreq(dstat):
 		if self.vars:
 			for cpu in self.vars:
 				if not os.access('/sys/devices/system/cpu/'+cpu+'/cpufreq/cpuinfo_cur_freq', os.R_OK):
-					raise Exception, 'Module cannot access acpi cpu frequency information'
+					raise Exception, 'Cannot access acpi cpu frequency information'
 			return True
-		raise Exception, 'No variables defined'
+		raise Exception, 'No statistics found'
 
 	def extract(self):
 		for cpu in self.vars:
