@@ -11,8 +11,7 @@ class dstat_rpcd(dstat):
 		self.init(self.vars, 1)
 
 	def extract(self):
-		self.fd.seek(0)
-		for line in self.fd.readlines():
+		for line in self.readlines():
 			l = line.split()
 			if not l or l[0] != 'rpc': continue
 			for i, name in enumerate(self.vars):
