@@ -1,21 +1,22 @@
 global iwlibs
-import iwlibs
+from pythonwifi import iwlibs
 
 class dstat_wifi(dstat):
 	def __init__(self):
 		self.name = 'wifi'
 		self.format = ('d', 3, 33)
+		self.check()
 		self.vars = iwlibs.getNICnames()
 		self.name = self.vars
 		self.nick = ('lnk', 's/n')
 		self.init(self.vars, 2)
 
 	def check(self): 
+		global iwlibs
 		try:
-			global iwlibs
-			import iwlibs
+			from pythonwifi import iwlibs
 		except:
-			raise Exception, 'Module needs the python-wifi module.'
+			raise Exception, 'Needs python-wifi module'
 		return True
 
 	def extract(self):
@@ -23,10 +24,9 @@ class dstat_wifi(dstat):
 			wifi = iwlibs.Wireless(name)
 			stat, qual, discard, missed_beacon = wifi.getStatistics()
 #			print qual.quality, qual.signallevel, qual.noiselevel
-			if qual.quality == 0 and qual.signallevel == qual.noiselevel == -101:
+			if qual.quality == 0 or qual.signallevel == -101 or qual.noiselevel == -101 or qual.signallevel == -256 or qual.noiselevel == -256:
 				self.val[name] = ( -1, -1 )
 			else:
-				self.val[name][0] = qual.quality * 100 / 160
-				self.val[name][1] = qual.signallevel * 100 / qual.noiselevel
+				self.val[name] = ( qual.quality, qual.signallevel * 100 / qual.noiselevel )
 
 # vim:ts=4:sw=4
